# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running `nixos-help`).

{ config, pkgs, ... }:
let
  # Import Home Manager with niv.
  home-manager = (import ../../nix/sources.nix).home-manager;
  #home-manager-source = import (import ../../nix/sources.nix).home-manager {};
in
{
  # Paths to other modules.
  # Compose this module out of smaller ones.
  # https://nixos.wiki/wiki/NixOS_modules
  imports =
    [
      # Include the results of the hardware scan.
      ./hardware-configuration.nix
      # Home Manager.
      (import "${home-manager}/nixos")
      #home-manager-source.nixos
      ../../modules/home-manager.nix
      # NUR.
      ../../modules/nur.nix

      ../../modules/base.nix
      #../../modules/base-headless.nix
      ../../modules/base-gnome.nix
      ../../modules/programs.nix
      ../../modules/autostart.nix
      ../../modules/wallpaper.nix
      ../../modules/fwupd-gnome.nix
      ../../modules/print-and-scan.nix
      #../../modules/fde-ssh-unlock.nix
      ../../modules/nextcloud-integration.nix

      ../../modules/gnome-config.nix
      ../../modules/gnome-extensions.nix
      ../../modules/gnome-fractional-scaling.nix
      ../../modules/git.nix
      ../../modules/zsh.nix
      ../../modules/nitrokey-gpg-smartcard.nix
      ../../modules/ssh-client.nix
      ../../modules/ssh-server.nix
      ../../modules/firefox.nix
      ../../modules/thunderbird.nix
      ../../modules/digikam-rawtherapee.nix
      ../../modules/ghostwriter.nix
      ../../modules/android.nix
      #../../modules/podman.nix
      ../../modules/docker.nix
      ../../modules/docker-pushrm.nix
      ../../modules/lid-switch-handling.nix
      ../../modules/sendmail-mta.nix
      #../../modules/journalwatch.nix
      #../../modules/waydroid.nix
      ../../modules/ntfs.nix
      #../../modules/veracrypt.nix
      #../../modules/btrbk
      #../../modules/spin-down.nix
    ];

  networking.hostName = "yodaTux";
  boot.initrd.luks.devices."luks-ea7099e3-320d-4eb3-a4c3-9910a9af817b".allowDiscards = true;

  # Systemd Journal entry:
  # S Sat Sep 23 16:11:52 2023 p4 kernel: TSC found unstable after boot, most likely due to broken BIOS. Use 'tsc=unstable'.
  boot.kernelParams = [ "tsc=unstable" ];

  # List all available kernel versions:
  #   `nix repl` -> `:l <nixpkgs>` -> `pkgs.linuxPackages` and press `TAB`
  # Default.
  #boot.kernelPackages = pkgs.linuxPackages;
  # Latest.
  boot.kernelPackages = pkgs.linuxPackages_latest;
  # Hardened.
  # https://archlinux.org/packages/extra/x86_64/linux-hardened/
  # -> https://github.com/anthraxx/linux-hardened
  #boot.kernelPackages = pkgs.linuxPackages_hardened;
  # Free/Libre.
  # https://en.wikipedia.org/wiki/Linux-libre
  #boot.kernelPackages = pkgs.linuxPackages-libre;
}
